{% load i18n css %}

<style>
    {{ 'django_pdf_view/style/example.css'|css }}
</style>

<div class="pdf-example__wrapper">
    <h1>{% trans 'Page' %} {{ page_number }} / {{ total_pages }}</h1>
    <p class="page-example__text">
        {% trans "And adding as many pages as you want to that PDF object!" %}
    </p>
</div>
