{% load i18n css %}

{% get_current_language as CURRENT_LANGUAGE_CODE %}

<!DOCTYPE html>
<html lang="{{ CURRENT_LANGUAGE_CODE }}">
<head>
    <meta charset="utf-8">
    <title>{% block title %}{{ title }}{% endblock title %}</title>
    <style>
        {% block style %}
            {{ 'django_pdf_view/style/pdf.css'|css }}
        {% endblock style %}
    </style>
</head>
<body>
{{ pages_html|safe }}
</body>
</html>
